<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Corporate_Prime
 */

if ( ! function_exists( 'corporate_prime_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
function corporate_prime_posted_on() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published updated" datetime="%3$s">%4$s</time>';
	}

	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);

	$posted_on = sprintf(
		esc_html_x( '%s', 'post date', 'corporate-prime' ),
		'<li><i class="fa fa-calendar"></i></li> <li><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a></li></ul>'
	);
	

	if (! post_password_required() && comments_open()) {
		echo '<ul class="blog-post-comment"><li><i class="fa fa-comment"></i></li><li>';
		comments_popup_link( esc_html__( '0 comment', 'corporate-prime' ), esc_html__( '1 Comment', 'corporate-prime' ), esc_html__( '% Comments', 'corporate-prime' ) );
		echo '</li></ul>';
	}

	$byline = sprintf(
		esc_html_x( ' %s' , 'post author', 'corporate-prime' ),
		'<li>'.__('by', 'corporate-prime').'<i class="fa fa-user icon"></i></li> <li><span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a> </span></li>'
	);

	echo '<ul class="blog-post-date posted-on">' . $posted_on . '</ul> <ul class="blog-post-comment byline"> ' . $byline . '</ul>'; // WPCS: XSS OK.
	
	edit_post_link(
		sprintf(
			/* translators: %s: Name of current post */
			esc_html__( 'Edit %s', 'corporate-prime' ),
			the_title( '<span class="screen-reader-text">"', '"</span>', false )
		),
		'<ul class="blog-post-edit edit-link"><li><i class="fa fa-pencil icon"></i>',
		'</li></ul>'
	);
	
}
endif;

if ( ! function_exists( 'corporate_prime_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function corporate_prime_entry_footer() {
	// Hide category and tag text for pages.
	if ( 'post' === get_post_type() ) {
		
		/* translators: used between list items, there is a space after the comma */
		$tags_list = get_the_tag_list( ' <li>', '</li> &nbsp; <li>', '<li> ');
		if ( $tags_list ) {
			printf( '<ul class="blog-post-category tags-links"> <li> <i class="fa fa-tags"></i> </li> ' . esc_html('%1$s') . ' </ul>', $tags_list ); // WPCS: XSS OK.
		}
		
		/* translators: used between list items, there is a space after the comma */
		$categories_list = get_the_category_list( ' </li> &nbsp; <li> ' );
		if ( $categories_list && corporate_prime_categorized_blog() ) {
			printf( '<ul class="blog-post-tags cat-links"> <li><i class="fa fa-thumb-tack"></i></li><li> ' . esc_html('%1$s') . ' </li></ul><div class="clearfix"></div>', $categories_list ); // WPCS: XSS OK.
		}

	}
	
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function corporate_prime_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'corporate_prime_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'corporate_prime_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so corporate_prime_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so corporate_prime_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in corporate_prime_categorized_blog.
 */
function corporate_prime_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'corporate_prime_categories' );
}
add_action( 'edit_category', 'corporate_prime_category_transient_flusher' );
add_action( 'save_post',     'corporate_prime_category_transient_flusher' );
